@@ -1,18 +1,26 @@
-app.controller('addressbooklistCtrl', ['$scope', 'AddressBookService', 'SettingsService', function(scope, AddressBookService, SettingsService) {
+angular.module('contactsApp')
+.controller('addressbooklistCtrl', function($scope, AddressBookService) {
 	var ctrl = this;
 
+	ctrl.loading = true;
+
 	AddressBookService.getAll().then(function(addressBooks) {
 		ctrl.addressBooks = addressBooks;
+		ctrl.loading = false;
 	});
 
+	ctrl.t = {
+		addressBookName : t('contacts', 'Address book name')
+	};
+
 	ctrl.createAddressBook = function() {
 		if(ctrl.newAddressBookName) {
 			AddressBookService.create(ctrl.newAddressBookName).then(function() {
 				AddressBookService.getAddressBook(ctrl.newAddressBookName).then(function(addressBook) {
 					ctrl.addressBooks.push(addressBook);
-					scope.$apply();
+					$scope.$apply();
 				});
 			});
 		}
 	};
-}]);
+});
