@@ -1,9 +1,10 @@
-app.directive('datepicker', function() {
+angular.module('contactsApp')
+.directive('datepicker', function() {
 	return {
 		restrict: 'A',
 		require : 'ngModel',
 		link : function (scope, element, attrs, ngModelCtrl) {
-			$(function(){
+			$(function() {
 				element.datepicker({
 					dateFormat:'yy-mm-dd',
 					minDate: null,
@@ -17,5 +18,3 @@ app.directive('datepicker', function() {
 		}
 	};
 });
-
-
