@@ -6,13 +6,18 @@ angular.module('contactsApp')
 	ctrl.type = undefined;
 	ctrl.isPreferred = false;
 	ctrl.t = {
-		poBox : t('contacts', 'Post Office Box'),
-		postalCode : t('contacts', 'Postal Code'),
+		poBox : t('contacts', 'Post office box'),
+		postalCode : t('contacts', 'Postal code'),
 		city : t('contacts', 'City'),
 		state : t('contacts', 'State or province'),
 		country : t('contacts', 'Country'),
 		address: t('contacts', 'Address'),
-		newGroup: t('contacts', '(new group)')
+		newGroup: t('contacts', '(new group)'),
+		familyName: t('contacts', 'Last name'),
+		firstName: t('contacts', 'First name'),
+		additionalNames: t('contacts', 'Additional names'),
+		honorificPrefix: t('contacts', 'Prefix'),
+		honorificSuffix: t('contacts', 'Suffix')
 	};
 
 	ctrl.availableOptions = ctrl.meta.options || [];
@@ -38,6 +43,18 @@ angular.module('contactsApp')
 			ctrl.availableOptions = ctrl.availableOptions.concat([{id: ctrl.type, name: displayName}]);
 		}
 	}
+	if (!_.isUndefined(ctrl.data) && !_.isUndefined(ctrl.data.namespace)) {
+		if (!_.isUndefined(ctrl.model.contact.props['X-ABLABEL'])) {
+			var val = _.find(this.model.contact.props['X-ABLABEL'], function(x) { return x.namespace === ctrl.data.namespace; });
+			ctrl.type = val.value;
+			if (!_.isUndefined(val)) {
+				// in case the type is not yet in the default list of available options we add it
+				if (!ctrl.availableOptions.some(function(e) { return e.id === val.value; } )) {
+					ctrl.availableOptions = ctrl.availableOptions.concat([{id: val.value, name: val.value}]);
+				}
+			}
+		}
+	}
 	ctrl.availableGroups = [];
 
 	ContactService.getGroups().then(function(groups) {
@@ -54,6 +71,28 @@ angular.module('contactsApp')
 		ctrl.model.updateContact();
 	};
 
+	ctrl.updateDetailedName = function () {
+		var fn = '';
+		if (ctrl.data.value[3]) {
+			fn += ctrl.data.value[3] + ' ';
+		}
+		if (ctrl.data.value[1]) {
+			fn += ctrl.data.value[1] + ' ';
+		}
+		if (ctrl.data.value[2]) {
+			fn += ctrl.data.value[2] + ' ';
+		}
+		if (ctrl.data.value[0]) {
+			fn += ctrl.data.value[0] + ' ';
+		}
+		if (ctrl.data.value[4]) {
+			fn += ctrl.data.value[4];
+		}
+
+		ctrl.model.contact.fullName(fn);
+		ctrl.model.updateContact();
+	};
+
 	ctrl.getTemplate = function() {
 		var templateUrl = OC.linkTo('contacts', 'templates/detailItems/' + ctrl.meta.template + '.html');
 		return $templateRequest(templateUrl);
