@@ -1,11 +1,12 @@
-app.directive('group', function() {
+angular.module('contactsApp')
+.directive('group', function() {
 	return {
 		restrict: 'A', // has to be an attribute to work with core css
 		scope: {},
 		controller: 'groupCtrl',
 		controllerAs: 'ctrl',
 		bindToController: {
-			group: "=data"
+			group: '=data'
 		},
 		templateUrl: OC.linkTo('contacts', 'templates/group.html')
 	};
