@@ -1,5 +1,6 @@
-app.filter('JSON2vCard', function() {
+angular.module('contactsApp')
+.filter('JSON2vCard', function() {
 	return function(input) {
 		return vCard.generate(input);
 	};
-});
\ No newline at end of file
+});
