@@ -1,4 +1,5 @@
-app.filter('orderDetailItems', ['vCardPropertiesService', function(vCardPropertiesService) {
+angular.module('contactsApp')
+.filter('orderDetailItems', function(vCardPropertiesService) {
 	'use strict';
 	return function(items, field, reverse) {
 
@@ -24,4 +25,4 @@ app.filter('orderDetailItems', ['vCardPropertiesService', function(vCardProperti
 		if(reverse) filtered.reverse();
 		return filtered;
 	};
-}]);
+});
