@@ -106,7 +106,7 @@ angular.module('contactsApp')
 			notifyObservers('create', newUid);
 			return newContact;
 		}).catch(function(e) {
-			console.log("Couldn't create", e);
+			OC.Notification.showTemporary(t('contacts', 'Contact could not be created.'));
 		});
 	};
 
@@ -150,6 +150,9 @@ angular.module('contactsApp')
 	};
 
 	this.update = function(contact) {
+		// update rev field
+		contact.rev(new Date().toISOString());
+
 		contact.syncVCard();
 
 		// update contact on server
