@@ -4,26 +4,33 @@ OC.L10N.register(
     "Contacts" : "جهات الاتصال",
     "Address book name" : "اسم دفتر العناوين",
     "Import" : "استيراد",
+    "The selected image is too big (max 1MB)" : "الصورة المختارة كبيرة جداً (الأكبر 1 ميغابايت)",
     "No contacts in here" : "لا توجد أية عناوين",
     "Name" : "الاسم",
     "Organization" : "المؤسسة",
     "Title" : "العنوان",
     "Add field ..." : "أضف حقلاً ...",
-    "Add contact" : "أضف جهة اتصال",
     "No search result for {query}" : "لم يظهر البحث عن {query} أي نتيجة",
-    "All contacts" : "كل الجهات",
-    "Not grouped" : "غير مصنف",
-    "Post Office Box" : "صندوق البريد",
-    "Postal Code" : "الرمز البريدي",
+    "_%n contact_::_%n contacts_" : ["جهة","جهة اتصال","جهتا اتصال","%n جهات اتصال","%n جهات اتصال","%n جهات"],
+    "Post office box" : "صندوق البريد",
+    "Postal code" : "الرمز البريدي.",
     "City" : "المدينة",
     "State or province" : "الولاية أو المنطقة.",
     "Country" : "البلد",
     "Address" : "عنوان",
     "(new group)" : "(مجموعة جديدة)",
+    "Last name" : "اسم العائلة",
+    "First name" : "الاسم الأول",
+    "Additional names" : "الاسماء الإضافية",
+    "Prefix" : "بادئة",
+    "Suffix" : "لاحقة",
+    "All contacts" : "كل الجهات",
+    "Not grouped" : "غير مصنف",
     "New contact" : "جهة إتصال جديدة",
     "{addressbook} shared by {owner}" : "{owner} شارك {addressbook}",
     "No contacts in file. Only VCard files are allowed." : "لاتوجد جهات في الملف.  ملفات VCard مسموح بها فقط.",
     "Nickname" : "كنية.\nلقب.",
+    "Detailed name" : "الاسم بالتفصيل",
     "Notes" : "الملاحظات",
     "Website" : "موقع إلكتروني",
     "Federated Cloud ID" : "معرّف السحابة الخارجية",
@@ -32,6 +39,7 @@ OC.L10N.register(
     "Other" : "آخر",
     "Groups" : "مجموعات",
     "Birthday" : "عيد ميلاد",
+    "Anniversary" : "ذكرى",
     "Email" : "البريد الإلكترونى",
     "Instant messaging" : "المراسلة الفورية",
     "Phone" : "الهاتف",
@@ -41,7 +49,7 @@ OC.L10N.register(
     "Fax work" : "فاكس العمل",
     "Pager" : "النداء",
     "Voice" : "صوت",
-    "Social Network" : "الشبكة الاجتماعية",
+    "Social network" : "شبكة اجتماعية",
     "Settings" : "الإعدادات"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
