@@ -9,17 +9,18 @@ OC.L10N.register(
     "Organization" : "Организация",
     "Title" : "Заглавие",
     "Add field ..." : "Добави приятел",
-    "Add contact" : "Добави контакт",
     "No search result for {query}" : "Няма намерени резултати за {query}",
-    "All contacts" : "Всички контакти",
-    "Not grouped" : "Негрупирани",
-    "Post Office Box" : "Офисна пощенска кутия",
-    "Postal Code" : "Пощенски код",
+    "Postal code" : "Пощенски код",
     "City" : "Град",
     "State or province" : "Страна или област",
     "Country" : "Държава",
     "Address" : "Адрес",
     "(new group)" : "(нова група)",
+    "Last name" : "Последно име",
+    "First name" : "Първо Име",
+    "Additional names" : "Други имена",
+    "All contacts" : "Всички контакти",
+    "Not grouped" : "Негрупирани",
     "New contact" : "Нов контакт",
     "{addressbook} shared by {owner}" : "{addressbook} споделена с {owner}",
     "No contacts in file. Only VCard files are allowed." : "Няма контакти в файла. Само VCard файлове са разрешени.",
@@ -40,7 +41,6 @@ OC.L10N.register(
     "Fax work" : "Факс служебен",
     "Pager" : "Пейджър",
     "Voice" : "Гласов",
-    "Social Network" : "Социялна мрежа",
     "Settings" : "Настройки"
 },
 "nplurals=2; plural=(n != 1);");
