@@ -4,25 +4,34 @@ OC.L10N.register(
     "Contacts" : "Kontakter",
     "Address book name" : "Adressebogsnavn",
     "Import" : "Importér",
+    "The selected image is too big (max 1MB)" : "Det valgte billede er for stort (max 1MB)",
     "No contacts in here" : "Ingen kontaktpersoner her",
     "Name" : "Navn",
     "Organization" : "Organisation",
     "Title" : "Titel",
     "Add field ..." : "Tilføj felt...",
-    "Add contact" : "Tilføj kontaktpeson.",
+    "+ New contact" : "Tilføj ny kontaktperson",
     "No search result for {query}" : "Ingen søgeresultater for  {query}",
-    "All contacts" : "Alle kontakter",
-    "Not grouped" : "Ikke i gruppe",
-    "Post Office Box" : "Postboks",
-    "Postal Code" : "Postnummer",
+    "_%n contact_::_%n contacts_" : ["%n kontaktperson","%n kontaktpersoner"],
+    "Post office box" : "Postboks",
+    "Postal code" : "Postnummer",
     "City" : "By",
     "State or province" : "Stat eller provins",
     "Country" : "Land",
     "Address" : "Adresse",
     "(new group)" : "(new group)",
+    "Last name" : "Efternavn",
+    "First name" : "Fornavn",
+    "Additional names" : "Mellemnavne",
+    "Prefix" : "Præfiks",
+    "Suffix" : "Suffiks",
+    "All contacts" : "Alle kontakter",
+    "Not grouped" : "Ikke i gruppe",
     "New contact" : "Ny kontakt",
     "{addressbook} shared by {owner}" : "{addressbook} delt af {owner}",
+    "No contacts in file. Only VCard files are allowed." : "Ingen kontakter i filen. Kun vCard filer accepteres.",
     "Nickname" : "Kaldenavn",
+    "Detailed name" : "Detaljeret navn",
     "Notes" : "Noter",
     "Website" : "Hjemmeside",
     "Federated Cloud ID" : "Federated Cloud ID",
@@ -31,6 +40,8 @@ OC.L10N.register(
     "Other" : "Andet",
     "Groups" : "Grupper",
     "Birthday" : "Fødselsdag",
+    "Anniversary" : "Årsdag",
+    "Date of death" : "Dødsdato",
     "Email" : "E-mail",
     "Instant messaging" : "Instant Messaging",
     "Phone" : "Telefon",
@@ -40,6 +51,7 @@ OC.L10N.register(
     "Fax work" : "Fax arbejde",
     "Pager" : "Personsøger",
     "Voice" : "Telefonsvarer",
+    "Social network" : "Socialt netværk",
     "Settings" : "Indstillinger"
 },
 "nplurals=2; plural=(n != 1);");
