@@ -4,26 +4,34 @@ OC.L10N.register(
     "Contacts" : "Contacts",
     "Address book name" : "Address book name",
     "Import" : "Import",
+    "The selected image is too big (max 1MB)" : "The selected image is too big (max 1MB)",
     "No contacts in here" : "No contacts in here",
     "Name" : "Name",
     "Organization" : "Organisation",
     "Title" : "Title",
     "Add field ..." : "Add field ...",
-    "Add contact" : "Add contact",
+    "+ New contact" : "+ New contact",
     "No search result for {query}" : "No search result for {query}",
-    "All contacts" : "All contacts",
-    "Not grouped" : "Not grouped",
-    "Post Office Box" : "Post Office Box",
-    "Postal Code" : "Postal Code",
+    "_%n contact_::_%n contacts_" : ["%n contact","%n contacts"],
+    "Post office box" : "Post office box",
+    "Postal code" : "Postcode",
     "City" : "City",
     "State or province" : "State or province",
     "Country" : "Country",
     "Address" : "Address",
     "(new group)" : "(new group)",
+    "Last name" : "Surname",
+    "First name" : "First-name",
+    "Additional names" : "Middle names",
+    "Prefix" : "Prefix",
+    "Suffix" : "Suffix",
+    "All contacts" : "All contacts",
+    "Not grouped" : "Not grouped",
     "New contact" : "New contact",
     "{addressbook} shared by {owner}" : "{addressbook} shared by {owner}",
     "No contacts in file. Only VCard files are allowed." : "No contacts in file. Only VCard files are allowed.",
     "Nickname" : "Nickname",
+    "Detailed name" : "Detailed name",
     "Notes" : "Notes",
     "Website" : "Website",
     "Federated Cloud ID" : "Federated Cloud ID",
@@ -32,6 +40,8 @@ OC.L10N.register(
     "Other" : "Other",
     "Groups" : "Groups",
     "Birthday" : "Birthday",
+    "Anniversary" : "Anniversary",
+    "Date of death" : "Date of death",
     "Email" : "Email",
     "Instant messaging" : "Instant messaging",
     "Phone" : "Phone",
@@ -41,7 +51,7 @@ OC.L10N.register(
     "Fax work" : "Fax work",
     "Pager" : "Pager",
     "Voice" : "Voice",
-    "Social Network" : "Social Network",
+    "Social network" : "Social network",
     "Settings" : "Settings"
 },
 "nplurals=2; plural=(n != 1);");
