@@ -9,17 +9,18 @@ OC.L10N.register(
     "Organization" : "Organisatsioon",
     "Title" : "Pealkiri",
     "Add field ..." : "Lisa väli ...",
-    "Add contact" : "Lisa kontakt",
     "No search result for {query}" : "Otsingutulemused sõnadele {query}",
-    "All contacts" : "Kõik kontaktid",
-    "Not grouped" : "Pole grupeeritud",
-    "Post Office Box" : "Postkast postkontoris",
-    "Postal Code" : "Postiindeks",
+    "Postal code" : "Postiindeks",
     "City" : "Linn",
     "State or province" : "Maakond",
     "Country" : "Riik",
     "Address" : "Aadress",
     "(new group)" : "(uus grupps)",
+    "Last name" : "Perekonnanimi",
+    "First name" : "Eesnimi",
+    "Additional names" : "Lisanimed",
+    "All contacts" : "Kõik kontaktid",
+    "Not grouped" : "Pole grupeeritud",
     "New contact" : "Uus kontakt",
     "{addressbook} shared by {owner}" : "{owner} jagas aadressiraamatut {addressbook}",
     "Nickname" : "Hüüdnimi",
