@@ -4,25 +4,32 @@ OC.L10N.register(
     "Contacts" : "Tengiliðir",
     "Address book name" : "Heiti nafnaskrár",
     "Import" : "Flytja inn",
+    "The selected image is too big (max 1MB)" : "Valin mynd er of stór (hám. 1MB)",
     "No contacts in here" : "Engir tengiliðir hér",
     "Name" : "Nafn",
     "Organization" : "Stofnun/félag",
     "Title" : "Titill",
     "Add field ..." : "Bæta við reit...",
-    "Add contact" : "Bæta við tengilið",
     "No search result for {query}" : "Engar leitarniðurstöður fyrir {query}",
-    "All contacts" : "Allir tengiliðir",
-    "Not grouped" : "Ekki hópað",
-    "Post Office Box" : "Pósthólf",
-    "Postal Code" : "Póstnúmer",
+    "Post office box" : "Pósthólf",
+    "Postal code" : "Póstnúmer",
     "City" : "Borg",
     "State or province" : "Ríki eða fylki",
     "Country" : "Land",
     "Address" : "Slóð",
     "(new group)" : "(nýr hópur)",
+    "Last name" : "Eftirnafn",
+    "First name" : "Eiginnafn",
+    "Additional names" : "Aukanöfn",
+    "Prefix" : "Forskeyti",
+    "Suffix" : "Viðskeyti",
+    "All contacts" : "Allir tengiliðir",
+    "Not grouped" : "Ekki hópað",
     "New contact" : "Nýr tengiliður",
     "{addressbook} shared by {owner}" : "{addressbook} deilt af {owner}",
+    "No contacts in file. Only VCard files are allowed." : "Engir tengiliðir í skrá. Einungis er tekið við VCard-skrám.",
     "Nickname" : "Gælunafn",
+    "Detailed name" : "Ítarlegt nafn",
     "Notes" : "Minnispunktar",
     "Website" : "Vefsvæði",
     "Federated Cloud ID" : "Skýjasambandsauðkenni (Federated Cloud ID)",
@@ -40,6 +47,7 @@ OC.L10N.register(
     "Fax work" : "Vinnufax",
     "Pager" : "Símboði",
     "Voice" : "Raddskilaboð",
+    "Social network" : "Samfélagsnet",
     "Settings" : "Stillingar"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
