@@ -12,12 +12,14 @@ OC.L10N.register(
     "Add contact" : "연락처 추가",
     "All contacts" : "모든 연락처",
     "Not grouped" : "그룹에 없음",
-    "Post Office Box" : "우편 사서함",
-    "Postal Code" : "우편 번호",
+    "Postal code" : "우편 번호",
     "City" : "도시",
     "State or province" : "도 및 광역시",
     "Country" : "국가",
     "Address" : "주소",
+    "Last name" : "성",
+    "First name" : "이름",
+    "Additional names" : "추가 이름",
     "New contact" : "새 연락처",
     "{addressbook} shared by {owner}" : "{owner} 님이 공유한 {addressbook}",
     "Nickname" : "별명",
