@@ -2,25 +2,34 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakter",
+    "Address book name" : "Navn på adressebok",
     "Import" : "Importer",
+    "The selected image is too big (max 1MB)" : "Det valgte bildet er for stort (maks 1MB)",
     "No contacts in here" : "Ingen kontakter her",
     "Name" : "Navn",
     "Organization" : "Organisasjon",
     "Title" : "Tittel",
     "Add field ..." : "Nytt felt ...",
-    "Add contact" : "Ny kontakt",
-    "All contacts" : "Alle kontakter",
-    "Not grouped" : "Ikke gruppert",
-    "Post Office Box" : "Postboks",
-    "Postal Code" : "Postnummer",
+    "No search result for {query}" : "Intet søkeresultat for {query}",
+    "Post office box" : "Postboks",
+    "Postal code" : "Postnummer",
     "City" : "By",
     "State or province" : "Stat eller fylke",
     "Country" : "Land",
     "Address" : "Adresse",
     "(new group)" : "(ny gruppe)",
+    "Last name" : "Etternavn",
+    "First name" : "Fornavn",
+    "Additional names" : "Ev. mellomnavn",
+    "Prefix" : "Prefiks",
+    "Suffix" : "Suffiks",
+    "All contacts" : "Alle kontakter",
+    "Not grouped" : "Ikke gruppert",
     "New contact" : "Ny kontakt",
     "{addressbook} shared by {owner}" : "{addressbook} delt av {owner}",
+    "No contacts in file. Only VCard files are allowed." : "Ingen kontakter i filen. Kun VCard-filer er tillatt.",
     "Nickname" : "Kallenavn",
+    "Detailed name" : "Detaljert navn",
     "Notes" : "Notater",
     "Website" : "Nettsted",
     "Federated Cloud ID" : "ID for sammenknyttet sky",
@@ -38,6 +47,7 @@ OC.L10N.register(
     "Fax work" : "Faks jobb",
     "Pager" : "Pager",
     "Voice" : "Svarer",
+    "Social network" : "Sosialt nettverk",
     "Settings" : "Innstillinger"
 },
 "nplurals=2; plural=(n != 1);");
