@@ -4,26 +4,34 @@ OC.L10N.register(
     "Contacts" : "Contactos",
     "Address book name" : "Nome do livro de endereços",
     "Import" : "Importar",
+    "The selected image is too big (max 1MB)" : "A imagem selecionada é demasiado grande (max 1MB)",
     "No contacts in here" : "Nenhum contacto aqui",
     "Name" : "Nome",
     "Organization" : "Organização",
     "Title" : "Título ",
     "Add field ..." : "Adicionar campo ...",
-    "Add contact" : "Adicionar contacto",
-    "No search result for {query}" : "Sem resultados de procura para {query}",
-    "All contacts" : "Todos os contactos",
-    "Not grouped" : "Não agrupados",
-    "Post Office Box" : "Caixa Postal",
-    "Postal Code" : "Código Postal",
+    "+ New contact" : "+ Novo contacto",
+    "No search result for {query}" : "Sem resultados de pesquisa para {query}",
+    "_%n contact_::_%n contacts_" : ["%n contacto","%n contactos"],
+    "Post office box" : "Apartado",
+    "Postal code" : "Código Postal",
     "City" : "Cidade",
     "State or province" : "Distrito",
     "Country" : "País",
     "Address" : "Endereço",
     "(new group)" : "(novo grupo)",
+    "Last name" : "Ultimo Nome",
+    "First name" : "Primeiro Nome",
+    "Additional names" : "Nomes adicionais",
+    "Prefix" : "Prefixo",
+    "Suffix" : "Sufixo",
+    "All contacts" : "Todos os contactos",
+    "Not grouped" : "Não agrupados",
     "New contact" : "Novo contacto",
     "{addressbook} shared by {owner}" : "{addressbook} partilhado por {owner}",
     "No contacts in file. Only VCard files are allowed." : "Nenhum contacto encontrado no ficheiro. Apenas são permitidos ficheiros VCard.",
     "Nickname" : "Alcunha",
+    "Detailed name" : "Nome em detalhe",
     "Notes" : "Notas",
     "Website" : "Site da Internet",
     "Federated Cloud ID" : "Id. da Nuvem Federada",
@@ -32,7 +40,9 @@ OC.L10N.register(
     "Other" : "Outro",
     "Groups" : "Grupos",
     "Birthday" : "Aniversário",
-    "Email" : "Correio Electrónico",
+    "Anniversary" : "Aniversário",
+    "Date of death" : "Data de falecimento",
+    "Email" : "Correio Eletrónico",
     "Instant messaging" : "Mensagens Instantâneas",
     "Phone" : "Telefone",
     "Mobile" : "Telemóvel",
@@ -41,7 +51,7 @@ OC.L10N.register(
     "Fax work" : "Fax do emprego",
     "Pager" : "Pager",
     "Voice" : "Voz",
-    "Social Network" : "Rede Social",
+    "Social network" : "Rede Social",
     "Settings" : "Definições"
 },
 "nplurals=2; plural=(n != 1);");
