@@ -4,26 +4,32 @@ OC.L10N.register(
     "Contacts" : "Kontakter",
     "Address book name" : "Adressboknamn",
     "Import" : "Importera",
+    "The selected image is too big (max 1MB)" : "Den valda bilden är för stor (max 1MB)",
     "No contacts in here" : "Det finns inga kontakter här",
     "Name" : "Namn",
     "Organization" : "Organisation",
     "Title" : "Rubrik",
     "Add field ..." : "Lägg till fält ...",
-    "Add contact" : "Lägg till en kontakt",
     "No search result for {query}" : "Inget sökresultat för {query}",
-    "All contacts" : "Alla kontakter",
-    "Not grouped" : "Inte grupperad",
-    "Post Office Box" : "Postbox",
-    "Postal Code" : "Postkod",
+    "Post office box" : "Postbox",
+    "Postal code" : "Postnummer",
     "City" : "Stad",
     "State or province" : "Stat eller provins",
     "Country" : "Land",
     "Address" : "Adress",
     "(new group)" : "(ny grupp)",
+    "Last name" : "Efternamn",
+    "First name" : "Förnamn",
+    "Additional names" : "Mellannamn",
+    "Prefix" : "Prefix",
+    "Suffix" : "Suffix",
+    "All contacts" : "Alla kontakter",
+    "Not grouped" : "Inte grupperad",
     "New contact" : "Ny kontakt",
     "{addressbook} shared by {owner}" : "{addressbook} delad av {owner}",
     "No contacts in file. Only VCard files are allowed." : "Inga kontakter i filen. Bara VCard-filer är tillåtna.",
     "Nickname" : "Smeknamn",
+    "Detailed name" : "Detaljerat namn",
     "Notes" : "Anteckningar",
     "Website" : "Webbplats",
     "Federated Cloud ID" : "Federerad Cloud ID",
@@ -41,7 +47,7 @@ OC.L10N.register(
     "Fax work" : "Fax arbete",
     "Pager" : "Personsökare",
     "Voice" : "Röst",
-    "Social Network" : "Socialt nätverk",
+    "Social network" : "Socialt nätverk",
     "Settings" : "Inställningar"
 },
 "nplurals=2; plural=(n != 1);");
