@@ -4,26 +4,34 @@ OC.L10N.register(
     "Contacts" : "ข้อมูลผู้ติดต่อ",
     "Address book name" : "สมุดชื่อที่อยู่",
     "Import" : "นำเข้า",
+    "The selected image is too big (max 1MB)" : "รูปภาพที่เลือกมีขนาดใหญ่เกินไป (ขนาดไม่ควรเกิน 1 เมกะไบต์)",
     "No contacts in here" : "ไม่มีรายชื่อในที่นี่",
     "Name" : "ชื่อ",
     "Organization" : "หน่วยงาน",
     "Title" : "ชื่อเรื่อง",
     "Add field ..." : "เพิ่มช่อง ...",
-    "Add contact" : "เพิ่มชื่อผู้ติดต่อ",
+    "+ New contact" : "เพิ่มรายชื่อใหม่",
     "No search result for {query}" : "ไม่พบผลลัพธ์การค้นหาสำหรับ {query}",
-    "All contacts" : "รายชื่อทั้งหมด",
-    "Not grouped" : "ไม่ถูกจัดกลุ่ม",
-    "Post Office Box" : "กล่องจดหมาย",
-    "Postal Code" : "รหัสไปรษณีย์",
+    "_%n contact_::_%n contacts_" : ["%n รายชื่อผู้ติดต่อ"],
+    "Post office box" : "กล่องจดหมาย",
+    "Postal code" : "รหัสไปรษณีย์",
     "City" : "เมือง",
     "State or province" : "รัฐหรือจังหวัด",
     "Country" : "ประเทศ",
     "Address" : "ที่อยู่",
     "(new group)" : "(กลุ่มใหม่)",
+    "Last name" : "นามสกุลจริง",
+    "First name" : "ชื่อจริง",
+    "Additional names" : "ชื่ออื่นๆ",
+    "Prefix" : "คำนำหน้า",
+    "Suffix" : "คำต่อท้าย",
+    "All contacts" : "รายชื่อทั้งหมด",
+    "Not grouped" : "ไม่ถูกจัดกลุ่ม",
     "New contact" : "รายชื่อผุ้ติดต่อใหม่",
     "{addressbook} shared by {owner}" : "{addressbook} ถูกแชร์โดย {owner}",
     "No contacts in file. Only VCard files are allowed." : "ไม่มีรายชื่อในไฟล์ เฉพาะไฟล์วีการ์ดจะได้รับอนุญาต",
     "Nickname" : "ชื่อเล่น",
+    "Detailed name" : "รายละเอียดชื่อ",
     "Notes" : "บันทึกย่อ",
     "Website" : "เว็บไซต์",
     "Federated Cloud ID" : "ไอดีคลาวด์ในเครือ",
@@ -32,6 +40,8 @@ OC.L10N.register(
     "Other" : "อื่นๆ",
     "Groups" : "กลุ่ม",
     "Birthday" : "วันเกิด",
+    "Anniversary" : "วันครบรอบ",
+    "Date of death" : "วันที่สิ้นสุด",
     "Email" : "อีเมล",
     "Instant messaging" : "ส่งข้อความโต้ตอบแบบทันที",
     "Phone" : "โทรศัพท์",
@@ -41,7 +51,7 @@ OC.L10N.register(
     "Fax work" : "แฟกซ์ที่ทำงาน",
     "Pager" : "เพจเจอร์",
     "Voice" : "เสียงพูด",
-    "Social Network" : "เครือข่ายสังคม",
+    "Social network" : "เครือข่ายทางสังคม",
     "Settings" : "ตั้งค่า"
 },
 "nplurals=1; plural=0;");
