@@ -9,17 +9,18 @@ OC.L10N.register(
     "Organization" : "組織",
     "Title" : "標題",
     "Add field ..." : "新增欄位…",
-    "Add contact" : "新增聯絡人",
     "No search result for {query}" : "沒有結果符合 {query}",
-    "All contacts" : "所有聯絡人",
-    "Not grouped" : "不在群組裡",
-    "Post Office Box" : "郵政信箱",
-    "Postal Code" : "郵遞區號",
+    "Postal code" : "郵遞區號",
     "City" : "城市",
     "State or province" : "州或省",
     "Country" : "國家",
     "Address" : "網址",
     "(new group)" : "（新群組）",
+    "Last name" : "姓氏",
+    "First name" : "名子",
+    "Additional names" : "別名",
+    "All contacts" : "所有聯絡人",
+    "Not grouped" : "不在群組裡",
     "New contact" : "新聯絡人",
     "{addressbook} shared by {owner}" : "{addressbook} 由 {owner} 分享",
     "Nickname" : "暱稱",
